==> qtwebengine-everywhere-opensource-src-6.2.6.zip: qtwebengine-everywhere-src-6.2.6/src/3rdparty/chromium/components/autofill/core/browser/payments/test_authentication_requester.cc <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/autofill/core/browser/payments/test_authentication_requester.h"

#include <string>

#include "build/build_config.h"
#include "components/autofill/core/browser/data_model/credit_card.h"

namespace autofill {

TestAuthenticationRequester::TestAuthenticationRequester() {}

TestAuthenticationRequester::~TestAuthenticationRequester() {}

base::WeakPtr<TestAuthenticationRequester>
TestAuthenticationRequester::GetWeakPtr() {
  return weak_ptr_factory_.GetWeakPtr();
}

void TestAuthenticationRequester::OnCVCAuthenticationComplete(
    const CreditCardCVCAuthenticator::CVCAuthenticationResponse& response) {
  did_succeed_ = response.did_succeed;
  if (did_succeed_) {
    DCHECK(response.card);
    number_ = response.card->number();
  }
}

#if defined(OS_ANDROID)
bool TestAuthenticationRequester::ShouldOfferFidoAuth() const {
  return false;
}

bool TestAuthenticationRequester::UserOptedInToFidoFromSettingsPageOnMobile()
    const {
  return false;
}
#endif

#if !defined(OS_IOS)
void TestAuthenticationRequester::OnFIDOAuthenticationComplete(
    const CreditCardFIDOAuthenticator::FidoAuthenticationResponse& response) {
  did_succeed_ = response.did_succeed;
  if (did_succeed_) {
    DCHECK(response.card);
    number_ = response.card->number();
  }
  failure_type_ = response.failure_type;
}

void TestAuthenticationRequester::OnFidoAuthorizationComplete(
    bool did_succeed) {
  did_succeed_ = did_succeed;
}

void TestAuthenticationRequester::IsUserVerifiableCallback(
    bool is_user_verifiable) {
  is_user_verifiable_ = is_user_verifiable;
}
#endif

}  // namespace autofill

==> qtwebengine-everywhere-opensource-src-6.2.7.zip: qtwebengine-everywhere-src-6.2.7/src/3rdparty/chromium/components/autofill/core/browser/payments/test_authentication_requester.cc <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/autofill/core/browser/payments/test_authentication_requester.h"

#include <string>

#include "build/build_config.h"
#include "components/autofill/core/browser/data_model/credit_card.h"

namespace autofill {

TestAuthenticationRequester::TestAuthenticationRequester() {}

TestAuthenticationRequester::~TestAuthenticationRequester() {}

base::WeakPtr<TestAuthenticationRequester>
TestAuthenticationRequester::GetWeakPtr() {
  return weak_ptr_factory_.GetWeakPtr();
}

void TestAuthenticationRequester::OnCVCAuthenticationComplete(
    const CreditCardCVCAuthenticator::CVCAuthenticationResponse& response) {
  did_succeed_ = response.did_succeed;
  if (*did_succeed_) {
    DCHECK(response.card);
    number_ = response.card->number();
  }
}

#if BUILDFLAG(IS_ANDROID)
bool TestAuthenticationRequester::ShouldOfferFidoAuth() const {
  return false;
}

bool TestAuthenticationRequester::UserOptedInToFidoFromSettingsPageOnMobile()
    const {
  return false;
}
#endif

#if !BUILDFLAG(IS_IOS)
void TestAuthenticationRequester::OnFIDOAuthenticationComplete(
    const CreditCardFIDOAuthenticator::FidoAuthenticationResponse& response) {
  did_succeed_ = response.did_succeed;
  if (*did_succeed_) {
    DCHECK(response.card);
    number_ = response.card->number();
  }
  failure_type_ = response.failure_type;
}

void TestAuthenticationRequester::OnFidoAuthorizationComplete(
    bool did_succeed) {
  did_succeed_ = did_succeed;
}

void TestAuthenticationRequester::IsUserVerifiableCallback(
    bool is_user_verifiable) {
  is_user_verifiable_ = is_user_verifiable;
}
#endif

void TestAuthenticationRequester::OnOtpAuthenticationComplete(
    const CreditCardOtpAuthenticator::OtpAuthenticationResponse& response) {
  did_succeed_ =
      response.result ==
      CreditCardOtpAuthenticator::OtpAuthenticationResponse::Result::kSuccess;
  if (*did_succeed_) {
    DCHECK(response.card);
    number_ = response.card->number();
  }
}

}  // namespace autofill
